@@ -1,15 +1,15 @@
 package bignum;
 use 5.006;
 
-$VERSION = '0.24';
+$VERSION = '0.32';
 use Exporter;
 @ISA 		= qw( bigint );
-@EXPORT_OK	= qw( PI e bexp bpi ); 
+@EXPORT_OK	= qw( PI e bexp bpi hex oct );
 @EXPORT 	= qw( inf NaN ); 
 
 use strict;
 use overload;
-require bigint;		# no "use" to avoid import being called
+use bigint ();
 
 ############################################################################## 
 
@@ -17,6 +17,8 @@ BEGIN
   {
   *inf = \&bigint::inf;
   *NaN = \&bigint::NaN;
+  *hex = \&bigint::hex;
+  *oct = \&bigint::oct;
   }
 
 # These are all alike, and thus faked by AUTOLOAD
@@ -68,23 +70,6 @@ sub in_effect
   }
 
 #############################################################################
-# the following two routines are for Perl 5.9.4 or later and are lexical
-
-sub _hex
-  {
-  return CORE::hex($_[0]) unless in_effect(1);
-  my $i = $_[0];
-  $i = '0x'.$i unless $i =~ /^0x/;
-  Math::BigInt->new($i);
-  }
-
-sub _oct
-  {
-  return CORE::oct($_[0]) unless in_effect(1);
-  my $i = $_[0];
-  return Math::BigInt->from_oct($i) if $i =~ /^0[0-7]/;
-  Math::BigInt->new($i);
-  }
 
 sub import 
   {
@@ -92,13 +77,10 @@ sub import
 
   $^H{bignum} = 1;					# we are in effect
 
-  my ($hex,$oct);
-
   # for newer Perls override hex() and oct() with a lexical version:
-  if ($] > 5.009003)
+  if ($] > 5.009004)
     {
-    $hex = \&_hex;
-    $oct = \&_oct;
+    bigint::_override();
     }
 
   # some defaults
@@ -116,14 +98,14 @@ sub import
       {
       # this causes upgrading
       $upgrade = $_[$i+1];		# or undef to disable
-      my $s = 2; $s = 1 if @a-$j < 2;	# avoid "can not modify non-existant..."
+      my $s = 2; $s = 1 if @a-$j < 2;	# avoid "can not modify non-existent..."
       splice @a, $j, $s; $j -= $s; $i++;
       }
     elsif ($_[$i] eq 'downgrade')
       {
       # this causes downgrading
       $downgrade = $_[$i+1];		# or undef to disable
-      my $s = 2; $s = 1 if @a-$j < 2;	# avoid "can not modify non-existant..."
+      my $s = 2; $s = 1 if @a-$j < 2;	# avoid "can not modify non-existent..."
       splice @a, $j, $s; $j -= $s; $i++;
       }
     elsif ($_[$i] =~ /^(l|lib|try|only)$/)
@@ -131,19 +113,19 @@ sub import
       # this causes a different low lib to take care...
       $lib_kind = $1; $lib_kind = 'lib' if $lib_kind eq 'l';
       $lib = $_[$i+1] || '';
-      my $s = 2; $s = 1 if @a-$j < 2;	# avoid "can not modify non-existant..."
+      my $s = 2; $s = 1 if @a-$j < 2;	# avoid "can not modify non-existent..."
       splice @a, $j, $s; $j -= $s; $i++;
       }
     elsif ($_[$i] =~ /^(a|accuracy)$/)
       {
       $a = $_[$i+1];
-      my $s = 2; $s = 1 if @a-$j < 2;	# avoid "can not modify non-existant..."
+      my $s = 2; $s = 1 if @a-$j < 2;	# avoid "can not modify non-existent..."
       splice @a, $j, $s; $j -= $s; $i++;
       }
     elsif ($_[$i] =~ /^(p|precision)$/)
       {
       $p = $_[$i+1];
-      my $s = 2; $s = 1 if @a-$j < 2;	# avoid "can not modify non-existant..."
+      my $s = 2; $s = 1 if @a-$j < 2;	# avoid "can not modify non-existent..."
       splice @a, $j, $s; $j -= $s; $i++;
       }
     elsif ($_[$i] =~ /^(v|version)$/)
@@ -156,17 +138,7 @@ sub import
       $trace = 1;
       splice @a, $j, 1; $j --;
       }
-    elsif ($_[$i] eq 'hex')
-      {
-      splice @a, $j, 1; $j --;
-      $hex = \&bigint::_hex_global;
-      }
-    elsif ($_[$i] eq 'oct')
-      {
-      splice @a, $j, 1; $j --;
-      $oct = \&bigint::_oct_global;
-      }
-    elsif ($_[$i] !~ /^(PI|e|bexp|bpi)\z/)
+    elsif ($_[$i] !~ /^(PI|e|bexp|bpi|hex|oct)\z/)
       {
       die ("unknown option $_[$i]");
       }
@@ -233,11 +205,6 @@ sub import
     {
     $self->export_to_level(1,$self,@a);           # export inf and NaN
     }
-  {
-    no warnings 'redefine';
-    *CORE::GLOBAL::oct = $oct if $oct;
-    *CORE::GLOBAL::hex = $hex if $hex;
-  }
   }
 
 sub PI () { Math::BigFloat->new('3.141592653589793238462643383279502884197'); }
@@ -267,7 +234,7 @@ bignum - Transparent BigNumber support for Perl
     print 2 ** 256,"\n";		# a normal Perl scalar now
   }
 
-  # for older Perls, note that this will be global:
+  # for older Perls, import into current package:
   use bignum qw/hex oct/;
   print hex("0x1234567890123490"),"\n";
   print oct("01234567890123490"),"\n";
@@ -364,12 +331,12 @@ allow you finer control over what get's done in which module/space. For
 instance, simple loop counters will be Math::BigInts under C<use bignum;> and
 this is slower than keeping them as Perl scalars:
 
-        perl -Mbignum -le 'for ($i = 0; $i < 10; $i++) { print ref($i); }'
+    perl -Mbignum -le 'for ($i = 0; $i < 10; $i++) { print ref($i); }'
 
 Please note the following does not work as expected (prints nothing), since
 overloading of '..' is not yet possible in Perl (as of v5.8.0):
 
-        perl -Mbignum -le 'for (1..2) { print ref($_); }'
+    perl -Mbignum -le 'for (1..2) { print ref($_); }'
 
 =head2 Options
 
@@ -386,7 +353,7 @@ than or equal to zero. See Math::BigInt's bround() function for details.
 
 	perl -Mbignum=a,50 -le 'print sqrt(20)'
 
-Note that setting precision and accurary at the same time is not possible.
+Note that setting precision and accuracy at the same time is not possible.
 
 =item p or precision
 
@@ -397,7 +364,7 @@ integer. See Math::BigInt's bfround() function for details.
 
 	perl -Mbignum=p,-50 -le 'print sqrt(20)'
 
-Note that setting precision and accurary at the same time is not possible.
+Note that setting precision and accuracy at the same time is not possible.
 
 =item t or trace
 
@@ -420,14 +387,16 @@ This will be hopefully fixed soon ;)
 =item hex
 
 Override the built-in hex() method with a version that can handle big
-integers. Note that under Perl older than v5.9.4, this will be global
-and cannot be disabled with "no bigint;".
+numbers. This overrides it by exporting it to the current package. Under
+Perl v5.10.0 and higher, this is not so necessary, as hex() is lexically
+overridden in the current scope whenever the bignum pragma is active.
 
 =item oct
 
 Override the built-in oct() method with a version that can handle big
-integers. Note that under Perl older than v5.9.4, this will be global
-and cannot be disabled with "no bigint;".
+numbers. This overrides it by exporting it to the current package. Under
+Perl v5.10.0 and higher, this is not so necessary, as oct() is lexically
+overridden in the current scope whenever the bigint pragma is active.
 
 =item v or version
 
@@ -570,7 +539,7 @@ Please see respective module documentation for further details.
 
 Using C<lib> warns if none of the specified libraries can be found and
 L<Math::BigInt> did fall back to one of the default libraries.
-To supress this warning, use C<try> instead:
+To suppress this warning, use C<try> instead:
 
 	use bignum try => 'GMP';
 
@@ -592,7 +561,7 @@ underneath at all.
 
 =head2 SIGN
 
-The sign is either '+', '-', 'NaN', '+inf' or '-inf' and stored seperately.
+The sign is either '+', '-', 'NaN', '+inf' or '-inf' and stored separately.
 You can access it with the sign() method.
 
 A sign of 'NaN' is used to represent the result when input arguments are not
@@ -600,7 +569,7 @@ numbers or as a result of 0/0. '+inf' and '-inf' represent plus respectively
 minus infinity. You will get '+inf' when dividing a positive number by 0, and
 '-inf' when dividing any negative number by 0.
 
-=head1 CAVAETS
+=head1 CAVEATS
 
 =over 2
 
@@ -650,7 +619,7 @@ The following modules are currently used by bignum:
 =head1 EXAMPLES
 
 Some cool command line examples to impress the Python crowd ;)
- 
+
 	perl -Mbignum -le 'print sqrt(33)'
 	perl -Mbignum -le 'print 2*255'
 	perl -Mbignum -le 'print 4.5+2*255'
